@@ -351,15 +351,19 @@ class PeleSimulation(SimulationRunner):
         """
         return self.parameters.processors - 1
 
-    def getNextIterationBox(self, outputFolder, resname, topologies=None, epoch=None):
+    def getNextIterationBox(self, outputFolder, resname, reschain, resnum, topologies=None, epoch=None):
         """
             Select the box for the next epoch, currently selecting the COM of
             the cluster with max SASA
 
             :param outputFolder: Folder to the trajectories
             :type outputFolder: str
-            :param resname: Name of the ligand in the pdb
+            :param resname: Residue name of the ligand in the system pdb
             :type resname: str
+            :param reschain: Chain name of the ligand in the system pdb
+            :type reschain: str
+            :param resnum: Residue number of the ligand in the system pdb
+            :type resnum: int
             :param topologies: Topology object containing the set of topologies needed for the simulation
             :type topologies: :py:class:`.Topology`
             :param epoch: Epoch of the trajectories to analyse
@@ -388,11 +392,11 @@ class PeleSimulation(SimulationRunner):
         snapshotNum = int(metrics[SASAcluster, -1])
         snapshot = utilities.getSnapshots(os.path.join(outputFolder, self.parameters.trajectoryName % trajNum))[snapshotNum]
         snapshotPDB = atomset.PDB()
-        snapshotPDB.initialise(snapshot, resname=resname, topology=topologies.getTopology(epoch, trajNum))
+        snapshotPDB.initialise(snapshot, resname=resname, chain=reschain, resnum=resnum, topology=topologies.getTopology(epoch, trajNum))
         self.parameters.boxCenter = str(snapshotPDB.getCOM())
         return
 
-    def selectInitialBoxCenter(self, initialStructuresAsString, resname):
+    def selectInitialBoxCenter(self, initialStructuresAsString, resname, reschain, resnum):
         """
             Select the coordinates of the first box, currently as the center of
             mass of the first initial structure provided
@@ -401,6 +405,10 @@ class PeleSimulation(SimulationRunner):
             :type initialStructuresAsString: str
             :param resname: Residue name of the ligand in the system pdb
             :type resname: str
+            :param reschain: Chain name of the ligand in the system pdb
+            :type reschain: str
+            :param resnum: Residue number of the ligand in the system pdb
+            :type resnum: int
 
             :returns str: -- string to be substitued in PELE control file
         """
@@ -418,7 +426,7 @@ class PeleSimulation(SimulationRunner):
         # trajectories because it was assumed that initial structures would
         # still be pdbs
         PDBinitial = atomset.PDB()
-        PDBinitial.initialise(initialStruct, resname=resname)
+        PDBinitial.initialise(initialStruct, resname=resname, chain=reschain, resnum=resnum)
         return repr(PDBinitial.getCOM())
 
     def runEquilibrationPELE(self, runningControlFile):
@@ -507,12 +515,17 @@ class PeleSimulation(SimulationRunner):
 
             :returns: dict -- Dictionary with pele control file options
         """
-        # Set small rotations and translations
-        peleControlFileDict["commands"][0]["Perturbation"]["parameters"]["translationRange"] = 0.5
-        peleControlFileDict["commands"][0]["Perturbation"]["parameters"]["rotationScalingFactor"] = 0.05
         # Remove dynamical changes in control file
         peleControlFileDict["commands"][0]["PeleTasks"][0].pop("exitConditions", None)
         peleControlFileDict["commands"][0]["PeleTasks"][0].pop("parametersChanges", None)
+        if "Perturbation" not in peleControlFileDict["commands"][0]:
+            # if the PELE control file contains no Perturbation block we do not
+            # need to change anything else
+            return peleControlFileDict
+
+        # Set small rotations and translations
+        peleControlFileDict["commands"][0]["Perturbation"]["parameters"]["translationRange"] = 0.5
+        peleControlFileDict["commands"][0]["Perturbation"]["parameters"]["rotationScalingFactor"] = 0.05
         if "Box" in peleControlFileDict["commands"][0]["Perturbation"]:
             # Set box_radius to 2
             peleControlFileDict["commands"][0]["Perturbation"]["Box"]["fixedCenter"] = "$BOX_CENTER"
@@ -579,7 +592,7 @@ class PeleSimulation(SimulationRunner):
         # but no more than 50
         return min(stepsPerProc, 50)
 
-    def equilibrate(self, initialStructures, outputPathConstants, reportFilename, outputPath, resname, processManager, topologies=None):
+    def equilibrate(self, initialStructures, outputPathConstants, reportFilename, outputPath, resname, reschain, resnum, processManager, topologies=None):
         """
             Run short simulation to equilibrate the system. It will run one
             such simulation for every initial structure and select appropiate
@@ -595,6 +608,10 @@ class PeleSimulation(SimulationRunner):
             :type outputPath: str
             :param resname: Residue name of the ligand in the system pdb
             :type resname: str
+            :param reschain: Chain name of the ligand in the system pdb
+            :type reschain: str
+            :param resnum: Residue number of the ligand in the system pdb
+            :type resnum: int
             :param processManager: Object to synchronize the possibly multiple processes
             :type processManager: :py:class:`.ProcessesManager`
             :param topologies: Topology object containing the set of topologies needed for the simulation
@@ -602,8 +619,8 @@ class PeleSimulation(SimulationRunner):
 
             :returns: list --  List with initial structures
         """
-        if resname is None:
-            raise utilities.RequiredParameterMissingException("Resname not specified in clustering block!!!")
+        if not any([x is not None for x in (resname, resnum, reschain)]):
+            raise utilities.RequiredParameterMissingException("Ligand information not specified in clustering block!!!")
         newInitialStructures = []
         newStructure = []
         if self.parameters.equilibrationLength is None:
@@ -622,7 +639,7 @@ class PeleSimulation(SimulationRunner):
             initialStructureString = self.createMultipleComplexesFilenames(1, outputPathConstants.tmpInitialStructuresEquilibrationTemplate, i+1, equilibration=True)
             equilibrationPeleDict["OUTPUT_PATH"] = equilibrationOutput
             equilibrationPeleDict["COMPLEXES"] = initialStructureString
-            equilibrationPeleDict["BOX_CENTER"] = self.selectInitialBoxCenter(structure, resname)
+            equilibrationPeleDict["BOX_CENTER"] = self.selectInitialBoxCenter(structure, resname, reschain, resnum)
             equilibrationPeleDict["BOX_RADIUS"] = 2
             equilibrationPeleDict["REPORT_NAME"] = reportFilename
             equilibrationPeleDict["TRAJECTORY_NAME"] = trajName
@@ -646,9 +663,9 @@ class PeleSimulation(SimulationRunner):
             if len(initialStructures) == 1 and self.parameters.equilibrationMode == blockNames.SimulationParams.equilibrationLastSnapshot:
                 newStructure.extend(self.selectEquilibrationLastSnapshot(self.parameters.processors, trajNames, topology=topologies.topologies[i]))
             elif self.parameters.equilibrationMode == blockNames.SimulationParams.equilibrationSelect:
-                newStructure.extend(self.selectEquilibratedStructure(self.parameters.processors, similarityColumn, resname, trajNames, reportNames, topology=topologies.topologies[i]))
+                newStructure.extend(self.selectEquilibratedStructure(self.parameters.processors, similarityColumn, resname, reschain, resnum, trajNames, reportNames, topology=topologies.topologies[i]))
             elif self.parameters.equilibrationMode == blockNames.SimulationParams.equilibrationCluster:
-                newStructure.extend(self.clusterEquilibrationStructures(resname, trajNames, reportNames, topology=topologies.topologies[i]))
+                newStructure.extend(self.clusterEquilibrationStructures(resname, reschain, resnum, trajNames, reportNames, topology=topologies.topologies[i]))
 
         if len(newStructure) > self.getWorkingProcessors():
             # if for some reason the number of selected structures exceeds
@@ -662,12 +679,16 @@ class PeleSimulation(SimulationRunner):
             newInitialStructures.append(newStructurePath)
         return newInitialStructures
 
-    def clusterEquilibrationStructures(self, resname, trajWildcard, reportWildcard, topology=None):
+    def clusterEquilibrationStructures(self, resname, reschain, resnum, trajWildcard, reportWildcard, topology=None):
         """
             Cluster the equilibration run
 
-            :param resname: Name of the ligand in the pdb
+            :param resname: Residue name of the ligand in the system pdb
             :type resname: str
+            :param reschain: Chain name of the ligand in the system pdb
+            :type reschain: str
+            :param resnum: Residue number of the ligand in the system pdb
+            :type resnum: int
             :param trajWildcard: Templetized path to trajectory files"
             :type trajWildcard: str
             :param reportWildcard: Templetized path to report files"
@@ -688,7 +709,7 @@ class PeleSimulation(SimulationRunner):
             snapshots = utilities.getSnapshots(trajWildcard % i)
             for nSnap, (line, snapshot) in enumerate(zip(report, snapshots)):
                 conformation = atomset.PDB()
-                conformation.initialise(snapshot, resname=resname, topology=topology)
+                conformation.initialise(snapshot, resname=resname, chain=reschain, resnum=resnum, topology=topology)
                 com = conformation.getCOM()
                 data.append([line[energyColumn], i, nSnap]+com)
         if not data:
@@ -741,7 +762,7 @@ class PeleSimulation(SimulationRunner):
 
         return initialStructures
 
-    def selectEquilibratedStructure(self, nTrajs, similarityColumn, resname, trajWildcard, reportWildcard, topology=None):
+    def selectEquilibratedStructure(self, nTrajs, similarityColumn, resname, reschain, resnum, trajWildcard, reportWildcard, topology=None):
         """
             Select a representative initial structure from the equilibration
             run
@@ -751,8 +772,12 @@ class PeleSimulation(SimulationRunner):
             :param similarityColumn: Column number of the similarity metric
                 (RMSD or distance)
             :type similarityColumn: int
-            :param resname: Name of the ligand in the pdb
+            :param resname: Residue name of the ligand in the system pdb
             :type resname: str
+            :param reschain: Chain name of the ligand in the system pdb
+            :type reschain: str
+            :param resnum: Residue number of the ligand in the system pdb
+            :type resnum: int
             :param trajWildcard: Templetized path to trajectory files"
             :type trajWildcard: str
             :param reportWildcard: Templetized path to report files"
@@ -779,12 +804,12 @@ class PeleSimulation(SimulationRunner):
                 snapshots = utilities.getSnapshots(trajWildcard % i)
                 report_values = []
                 if i == 1:
-                    initial.initialise(snapshots.pop(0), resname=resname, topology=topology)
+                    initial.initialise(snapshots.pop(0), resname=resname, chain=reschain, resnum=resnum, topology=topology)
                     report_values.append([0, report[0, energyColumn]])
                     report = report[1:, :]
                 for j, snap in enumerate(snapshots):
                     pdbConformation = atomset.PDB()
-                    pdbConformation.initialise(snap, resname=resname, topology=topology)
+                    pdbConformation.initialise(snap, resname=resname, chain=reschain, resnum=resnum, topology=topology)
                     report_values.append([RMSDCalc.computeRMSD(initial, pdbConformation), report[j, energyColumn]])
             else:
                 report_values = report[:, cols]
@@ -914,7 +939,7 @@ class MDSimulation(SimulationRunner):
             # arbitrarely return the first ligand name
             return self.parameters.ligandName[0]
 
-    def equilibrate(self, initialStructures, outputPathConstants, reportFilename, outputPath, resnames, processManager, topologies=None):
+    def equilibrate(self, initialStructures, outputPathConstants, reportFilename, outputPath, resnames, reschain, resnum, processManager, topologies=None):
         """
             Run short simulation to equilibrate the system. It will run one
             such simulation for every initial structure
@@ -931,6 +956,10 @@ class MDSimulation(SimulationRunner):
             :type outputPath: str
             :param resnames: Residue name of the ligands in the system pdb
             :type resnames: list
+            :param reschain: Chain name of the ligand in the system pdb
+            :type reschain: str
+            :param resnum: Residue number of the ligand in the system pdb
+            :type resnum: int
             :param processManager: Object to synchronize the possibly multiple processes
             :type processManager: :py:class:`.ProcessesManager`
             :param topology: Topology object
@@ -958,26 +987,27 @@ class MDSimulation(SimulationRunner):
         os.chdir(outputPathConstants.tmpFolder)
         temporalFolder = os.getcwd()
         Tleapdict = {"LIGANDS": "", "DUM": ""}
-        for charge, resname in zip(self.parameters.ligandCharge, self.parameters.ligandName):
-            ligandPDB = self.extractLigand(initialStructures[0][1], resname, "", processManager.id)
-            ligandmol2 = "%s.mol2" % resname
-            ligandfrcmod = "%s.frcmod" % resname
-            antechamberDict = {"LIGAND": ligandPDB, "OUTPUT": ligandmol2, "CHARGE": charge}
-            parmchkDict = {"MOL2": ligandmol2, "OUTPUT": ligandfrcmod}
-            if processManager.isMaster() and not self.parameters.customparamspath and resname is not None:
-                self.prepareLigand(antechamberDict, parmchkDict)
-            amber_file_path = ""
-            # Change the Mol2 and Frcmod path to the new user defined path
-            if self.parameters.customparamspath and resname is not None:
-                if not os.path.exists(self.parameters.customparamspath):
-                    # As the working directory has changed, eval if the given path is a global or relative one.
-                    self.parameters.customparamspath = os.path.join(workingdirectory, self.parameters.customparamspath)
+        if self.parameters.ligandCharge is not None and self.parameters.ligandName is not None:
+            for charge, resname in zip(self.parameters.ligandCharge, self.parameters.ligandName):
+                ligandPDB = self.extractLigand(initialStructures[0][1], resname, "", processManager.id)
+                ligandmol2 = "%s.mol2" % resname
+                ligandfrcmod = "%s.frcmod" % resname
+                antechamberDict = {"LIGAND": ligandPDB, "OUTPUT": ligandmol2, "CHARGE": charge}
+                parmchkDict = {"MOL2": ligandmol2, "OUTPUT": ligandfrcmod}
+                if processManager.isMaster() and not self.parameters.customparamspath and resname is not None:
+                    self.prepareLigand(antechamberDict, parmchkDict)
+                amber_file_path = ""
+                # Change the Mol2 and Frcmod path to the new user defined path
+                if self.parameters.customparamspath and resname is not None:
                     if not os.path.exists(self.parameters.customparamspath):
-                        raise FileNotFoundError("No custom parameters found in the given path")
-                ligandmol2 = os.path.join(self.parameters.customparamspath, ligandmol2)
-                ligandfrcmod = os.path.join(self.parameters.customparamspath, ligandfrcmod)
-                amber_file_path = self.parameters.customparamspath
-            Tleapdict["LIGANDS"] += "{} = loadmol2 {}\nloadamberparams {}\n".format(resname, ligandmol2, ligandfrcmod)
+                        # As the working directory has changed, eval if the given path is a global or relative one.
+                        self.parameters.customparamspath = os.path.join(workingdirectory, self.parameters.customparamspath)
+                        if not os.path.exists(self.parameters.customparamspath):
+                            raise FileNotFoundError("No custom parameters found in the given path")
+                    ligandmol2 = os.path.join(self.parameters.customparamspath, ligandmol2)
+                    ligandfrcmod = os.path.join(self.parameters.customparamspath, ligandfrcmod)
+                    amber_file_path = self.parameters.customparamspath
+                Tleapdict["LIGANDS"] += "{} = loadmol2 {}\nloadamberparams {}\n".format(resname, ligandmol2, ligandfrcmod)
         if self.parameters.boxCenter or self.parameters.cylinderBases:
             if self.parameters.boxType == blockNames.SimulationParams.sphere:
                 prep_template = constants.AmberTemplates.DUM_prep
@@ -1107,7 +1137,7 @@ class MDSimulation(SimulationRunner):
 
         with open(PDBtoOpen, "r") as inp:
             for line in inp:
-                if resname in line and line.startswith("HETATM"):
+                if resname in line and (line.startswith("ATOM") or line.startswith("HETATM")):
                     if (resname, line[21]) in line_dict:
                         line_dict[(resname, line[21])] += line
                     else:
@@ -1524,8 +1554,9 @@ class RunnerBuilder:
                 params.ligandName = [params.ligandName]
             if isinstance(params.ligandCharge, numbers.Real):
                 params.ligandCharge = [params.ligandCharge]
-            if len(params.ligandName) != len(params.ligandCharge):
-                raise utilities.ImproperParameterValueException("The smae amount of ligand names and charges should be specified")
+            if params.ligandName is not None and params.ligandCharge is not None:
+                if len(params.ligandName) != len(params.ligandCharge):
+                    raise utilities.ImproperParameterValueException("The same amount of ligand names and charges should be specified")
             params.cofactors = paramsBlock.get(blockNames.SimulationParams.cofactors)
             params.constraints = paramsBlock.get(blockNames.SimulationParams.constraints)
             params.postprocessing = paramsBlock.get(blockNames.SimulationParams.postprocessing, True)
