@@ -1,16 +1,16 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
-from builtins import range
-from six import reraise as raise_
 import os
 import ast
 import sys
-import six
 import glob
 import json
 import errno
 import socket
 import shutil
 import string
+from builtins import range
+import six
+from six import reraise as raise_
 import numpy as np
 import mdtraj as md
 from scipy import linalg
@@ -322,6 +322,31 @@ def getTrajNum(trajFilename):
     return int(trajFilename.split("_")[-1][:-4])
 
 
+def getFileSuffix(filename, separator="_"):
+    """
+        Gets the suffix appendend to a file name
+
+        :param filename: filename
+        :type filename: str
+        :param separator: character used as separator for the suffix
+        :type separator: str
+
+        :returns: int -- Trajectory number
+    """
+    name, _ = os.path.splitext(filename)
+    return name.split(separator)[-1]
+
+def isReport(reportFilename):
+    """
+        Checks whether the file is a PELE report
+
+        :param reportFilename: Trajectory filename
+        :type reportFilename: str
+
+        :returns: bool -- Whether the file is a PELE report
+    """
+    return getFileSuffix(reportFilename).isdigit()
+
 def getReportNum(reportFilename):
     """
         Gets the report number
@@ -331,8 +356,7 @@ def getReportNum(reportFilename):
 
         :returns: int -- Report number
     """
-    name, _ = os.path.splitext(reportFilename)
-    return int(name.split("_")[-1])
+    return int(getFileSuffix(reportFilename))
 
 
 def getPrmtopNum(prmtopFilename):
@@ -383,7 +407,7 @@ def assertSymmetriesDict(symmetries, PDB):
         print("Symmetry dictionary correctly defined!")
 
 
-def getRMSD(traj, nativePDB, resname, symmetries, topology=None):
+def getRMSD(traj, nativePDB, resname, reschain, resnum, symmetries, topology=None):
     """
         Computes the RMSD of a trajectory, given a native and symmetries
 
@@ -391,8 +415,12 @@ def getRMSD(traj, nativePDB, resname, symmetries, topology=None):
         :type traj: str
         :param nativePDB:  Native PDB object
         :type native PDB: :py:class:`.PDB`
-        :param resname: Resname to compute its RMSD
+        :param resname: Residue name of the ligand in the system pdb
         :type resname: str
+        :param reschain: Chain name of the ligand in the system pdb
+        :type reschain: str
+        :param resnum: Residue number of the ligand in the system pdb
+        :type resnum: int
         :param symmetries: Symmetries dictionary list with independent symmetry groups
         :type symmetries: list of dict
         :param topology: Topology for non-pdb trajectories
@@ -406,7 +434,7 @@ def getRMSD(traj, nativePDB, resname, symmetries, topology=None):
     RMSDCalc = RMSDCalculator.RMSDCalculator(symmetries)
     for i, snapshot in enumerate(snapshots):
         snapshotPDB = atomset.PDB()
-        snapshotPDB.initialise(snapshot, resname=resname, topology=topology)
+        snapshotPDB.initialise(snapshot, resname=resname, chain=reschain, resnum=resnum, topology=topology)
 
         rmsds[i] = RMSDCalc.computeRMSD(nativePDB, snapshotPDB)
 
@@ -966,3 +994,35 @@ def get_string_from_array(array, sep=", ", decimals=None, remove_newlines=True):
     if remove_newlines:
         return representation.replace('\n', '')
     return representation
+
+
+def get_file_name_extension(full_path):
+    """
+        Get the name and the extension of the file pointed by full_path
+
+        :param full_path: Path to the file
+        :type full_path: str
+    """
+    return os.path.splitext(os.path.split(full_path)[1])
+
+
+def get_file_name(full_path):
+    """
+        Get the name of the file pointed by full_path
+
+        :param full_path: Path to the file
+        :type full_path: str
+    """
+    name, _ = get_file_name_extension(full_path)
+    return name
+
+
+def get_file_extension(full_path):
+    """
+        Get the extension of the file pointed by full_path
+
+        :param full_path: Path to the file
+        :type full_path: str
+    """
+    _, ext = get_file_name_extension(full_path)
+    return ext
